/****************************************************************************/
/*                                                                          */
/*                      Chaine de CAO & VLSI   Alliance                     */
/*                                                                          */
/*    Produit : TTV Version 1                                               */
/*    Fichier : ttv100.h                                                    */
/*                                                                          */
/*    (c) copyright 1991-1995 Laboratoire MASI equipe CAO & VLSI            */
/*    Tous droits reserves                                                  */
/*    Support : e-mail cao-vlsi@masi.ibp.fr                                 */
/*                                                                          */
/*    Auteur(s) : DIOURY Karim                                              */
/*                                                                          */
/****************************************************************************/
/* les structures et base de donnees de TTV                                 */
/****************************************************************************/

#ifndef TTV
#define TTV

/* LISTE DES INCLUDE */
#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include <string.h>
#include <time.h>

/* LISTE DES DEFINE */

/* defines generaux */
#define TTV_MAX_BLOC       256                  /* taille des blocs          */
#define TTV_MAX_SBLOC      256                  /* taille des sblocs         */
#define TTV_MAX_LBLOC      512                  /* taille des lblocs         */
#define TTV_ERROR          1                    /* ttv error                 */
#define TTV_WARNING        2                    /* ttv warning               */
#define TTV_DATE_LOCAL     1                    /* date et heure local       */
#define TTV_DATE_GMT       2                    /* date et heure gmt         */
#define TTV_LANG_E         'E'                  /* langue anglaise           */ 
#define TTV_LANG_F         'F'                  /* langue francaise          */ 
#define TTV_SAVE_PATH      'Y'                  /* sauve les chemins         */ 
#define TTV_NOTSAVE_PATH   'N'                  /* ne sauve pas les chemins  */ 
#define TTV_SAVE_ALLPATH   'A'                  /* sauve tous les chemins    */ 
#define TTV_OLD_MAX        ((long) 0x7fffffff ) /* age le plus vieux         */ 
#define TTV_OLD_MIN        ((long) 0x3fffffff ) /* rajeunissement            */ 
#define TTV_ALLOC_MAX      ((long) 0x7fffffff ) /* nb d'allocation max s & l */ 
#define TTV_UP             'U'                  /* transition montante       */
#define TTV_DOWN           'D'                  /* transition descendante    */
#define TTV_DELAY_MAX      ((long) 0x7fffffff ) /* delai maximum autorise    */
#define TTV_DELAY_MIN      ((long) 0x80000000 ) /* delai minimum autorise    */

/* status des ttvfig */
#define TTV_STS_MARQUE     ((long) 0x10000000 ) /* ttvfig marque             */
#define TTV_STS_MODEL      ((long) 0x20000000 ) /* ttvfig model              */
#define TTV_STS_NOT_FREE   ((long) 0x00080000 ) /* ttvfig a conserver        */
#define TTV_STS_FREE_2     ((long) 0x00040000 ) /* ttvfig a liberer en 2     */
#define TTV_STS_FREE_1     ((long) 0x00020000 ) /* ttvfig a liberer en 1     */
#define TTV_STS_FREE_0     ((long) 0x00010000 ) /* ttvfig a liberer en 0     */
#define TTV_STS_FREE_MASK  ((long) 0x000F0000 ) /* ttvfig a conserver        */
#define TTV_STS_HEAD       ((long) 0x00100000 ) /* sommet de la ttvfig       */
#define TTV_STS_DUAL_P     ((long) 0x00200000 ) /* dual des liens P          */
#define TTV_STS_DUAL_J     ((long) 0x00400000 ) /* dual des liens J          */
#define TTV_STS_DUAL_T     ((long) 0x00800000 ) /* dual des liens T          */
#define TTV_STS_DUAL_F     ((long) 0x01000000 ) /* dual des liens F          */
#define TTV_STS_DUAL_E     ((long) 0x02000000 ) /* dual des liens E          */
#define TTV_STS_DUAL_D     ((long) 0x04000000 ) /* dual des liens D          */
#define TTV_STS_DUAL       ((long) 0x07e00000 ) /* dual des liens            */
#define TTV_STS_HEADER     ((long) 0x00000001 ) /* ttvfig avec H et X        */
#define TTV_STS_CARACSIG   ((long) 0x00000002 ) /* ttvfig avec carac sig     */
#define TTV_STS_CARACLINED ((long) 0x00000004 ) /* ttvfig avec carac line D  */
#define TTV_STS_CARACLINET ((long) 0x00000008 ) /* ttvfig avec carac line T  */
#define TTV_STS_CARAC      ((long) 0x0000000f ) /* ttvfig avec carac         */
#define TTV_STS_C          ((long) 0x00000010 ) /* noeud C                   */
#define TTV_STS_L          ((long) 0x00000020 ) /* noeud QLRI                */
#define TTV_STS_S          ((long) 0x00000040 ) /* noeud S                   */
#define TTV_STS_SE         ((long) 0x00000080 ) /* SE ref dans la ttvfig     */
#define TTV_STS_P          ((long) 0x00000100 ) /* chemin complet            */
#define TTV_STS_J          ((long) 0x00000200 ) /* chemin partiel sur un T   */
#define TTV_STS_T          ((long) 0x00000400 ) /* chemin connecteur         */
#define TTV_STS_F          ((long) 0x00001000 ) /* temps portes interne      */
#define TTV_STS_E          ((long) 0x00002000 ) /* temps porte externe       */
#define TTV_STS_D          ((long) 0x00004000 ) /* temps porte connecteur    */
#define TTV_STS_DENOTINPT  ((long) 0x00008000 ) /* DE pas dans PT            */
#define TTV_STS_DTX        ((long) 0x000070f7 ) /* fichier dtx               */
#define TTV_STS_TTX        ((long) 0x0000073b ) /* fichier ttx               */
#define TTV_STS_ALL        ((long) 0x000077ff ) /* ttvfig complet            */
#define TTV_STS_L_P        ((long) 0x00000120 ) /* QLRIN+P                   */
#define TTV_STS_L_J        ((long) 0x00000220 ) /* QLRIN+J                   */
#define TTV_STS_L_PJ       ((long) 0x00000320 ) /* QLRIN+PJ                  */
#define TTV_STS_LS         ((long) 0x00000060 ) /* QLRIN+S                   */
#define TTV_STS_LS_F       ((long) 0x00001060 ) /* QLRIN+S+F                 */
#define TTV_STS_LS_E       ((long) 0x00002060 ) /* QLRIN+S+E                 */
#define TTV_STS_LS_FE      ((long) 0x00003060 ) /* QLRIN+S+EF                */
#define TTV_STS_CL         ((long) 0x00000030 ) /* CQLRIN                    */
#define TTV_STS_CL_T       ((long) 0x00000430 ) /* CQLRIN+T                  */
#define TTV_STS_CL_PJT     ((long) 0x00000730 ) /* CQLRIN+PJT                */
#define TTV_STS_CLS        ((long) 0x00000070 ) /* CQLRIN+S                  */
#define TTV_STS_CLS_D      ((long) 0x00004070 ) /* CQLRIN+S+D                */
#define TTV_STS_CLS_FED    ((long) 0x00007070 ) /* CQLRIN+S+FED              */

/* type user des ttvfig */
#define TTV_STS_HTAB_L     ((long) 0x00000001 ) /* table de hash pour L      */
#define TTV_STS_HTAB_S     ((long) 0x00000002 ) /* table de hash pour S      */

/* type des signaux */
#define TTV_SIG_C          ((long) 0x00000001 ) /* signal connecteur         */
#define TTV_SIG_CI         ((long) 0x00000003 ) /* signal connecteur in      */
#define TTV_SIG_CO         ((long) 0x00000005 ) /* signal connecteur out     */
#define TTV_SIG_CZ         ((long) 0x00000015 ) /* signal connecteur hz      */
#define TTV_SIG_CB         ((long) 0x00000027 ) /* signal connecteur inout   */
#define TTV_SIG_CT         ((long) 0x00000047 ) /* signal connecteur tstate  */
#define TTV_SIG_CX         ((long) 0x00000081 ) /* signal connecteur unknow  */
#define TTV_SIG_N          ((long) 0x00000008 ) /* signal noeud con pour RC  */
#define TTV_SIG_CQ         ((long) 0x00000101 ) /* signal connecteur cmd     */
#define TTV_SIG_CL         ((long) 0x00000201 ) /* signal connecteur cmd     */
#define TTV_SIG_CR         ((long) 0x00000401 ) /* signal connecteur cmd     */
#define TTV_SIG_NQ         ((long) 0x00000108 ) /* con rc pour cmd           */
#define TTV_SIG_NL         ((long) 0x00000208 ) /* con rc pour cmd           */
#define TTV_SIG_NR         ((long) 0x00000408 ) /* con rc pour cmd           */
#define TTV_SIG_Q          ((long) 0x00000100 ) /* signal latch command      */
#define TTV_SIG_L          ((long) 0x00000200 ) /* signal latch              */
#define TTV_SIG_LL         ((long) 0x00000202 ) /* signal latch latch        */
#define TTV_SIG_LF         ((long) 0x00000204 ) /* signal flipflop           */
#define TTV_SIG_R          ((long) 0x00000400 ) /* signal precharge          */
#define TTV_SIG_I          ((long) 0x00000800 ) /* signal intermediaire      */
#define TTV_SIG_S          ((long) 0x00001000 ) /* signal non CQLRIN         */

/* marquage des signaux */
#define TTV_SIG_EXT        ((long) 0x00002000 ) /* signal exterieur          */
#define TTV_SIG_TYPE       ((long) 0x00001FFF ) /* masquage du type signal   */
#define TTV_SIG_TYPECON    ((long) 0x000000FF ) /* masquage des connecteurs  */
#define TTV_SIG_LEVEL      ((long) 0x00FF0000 ) /* masquage des connecteurs  */
#define TTV_SIG_MARQUE     ((long) 0x10000000 ) /* signal marque             */
#define TTV_SIG_F          ((long) 0x20000000 ) /* signal libre              */
#define TTV_SIG_BYPASSOUT  ((long) 0x40000000 ) /* signal non-important OUT  */
#define TTV_SIG_BYPASSIN   ((long) 0x80000000 ) /* signal non-important IN   */
#define TTV_SIG_MASKIN     ((long) 0x01000000 ) /* signal mask pour in       */
#define TTV_SIG_MASKOUT    ((long) 0x02000000 ) /* signal mask pour out      */
#define TTV_SIG_MINSIG     ((long) 0x04000000 ) /* marquage signaux d'entree */
#define TTV_SIG_MOUTSIG    ((long) 0x08000000 ) /* marquage signaux sortie   */

/* type user des signaux */
#define TTV_SIG_INDEX      ((long) 0x00000001 ) /* index du signal           */
#define TTV_CMD_INDEX      ((long) 0x00000002 ) /* index de la command       */
#define TTV_SIG_CARAC      ((long) 0x00000003 ) /* carac elec pour connector */
#define TTV_SIG_CMD        ((long) 0x00000004 ) /* cmd pour L et R           */
#define TTV_SIG_CMDNEW     ((long) 0x00000005 ) /* nouveau cmd ttvfig pere   */
#define TTV_SIG_CMDOLD     ((long) 0x00000006 ) /* ancien cmd ttvfig fils    */
#define TTV_SIG_INSIG      ((long) 0x00000007 ) /* liste signaux d'entree    */
#define TTV_SIG_OUTSIG     ((long) 0x00000008 ) /* liste signaux de sortie   */

/* type des evenements */
#define TTV_NODE_MARQUE    ((long) 0x10000000 ) /* noeud marque              */
#define TTV_NODE_CMDMARQUE ((long) 0x20000000 ) /* cmd marque Pour L         */
#define TTV_NODE_UP        ((long) 0x00000001 ) /* noeud niveau haut         */
#define TTV_NODE_DOWN      ((long) 0x00000002 ) /* noeud niveau bas          */
#define TTV_NODE_INFIFO    ((long) 0x00000010 ) /* noeud deja empile         */
#define TTV_NODE_OUTFIFO   (~(TTV_NODE_INFIFO)) /* noeud non-empile          */
#define TTV_NODE_STOP      ((long) 0x00000100 ) /* noeud point d'arret       */
#define TTV_NODE_IMAX      ((long) 0x00000200 ) /* noeud fact pour max       */
#define TTV_NODE_IMIN      ((long) 0x00000400 ) /* noeud fact pour min       */
#define TTV_NODE_BEGIN     ((long) 0x00001000 ) /* debut de chaine           */
#define TTV_NODE_END       ((long) 0x00002000 ) /* fin de chaine             */

/* type user des evenements */
#define TTV_NODE_DUALLINE  ((long) 0x00000001 ) /* liens dual                */
#define TTV_NODE_DUALPATH  ((long) 0x00000002 ) /* chemins dual              */
#define TTV_NODE_INCHAIN   ((long) 0x00000003 ) /* entree vue par un noeud   */
#define TTV_NODE_IN        ((long) 0x00000004 ) /* noeud d'entree            */
#define TTV_NODE_AVNODE    ((long) 0x00000005 ) /* noeud precedent           */
#define TTV_NODE_DELAYLOOP ((long) 0x00000006 ) /* delay de bascule          */

/* type des lines */
#define TTV_LINE_P         ((long) 0x00000001 ) /* lien de type P            */
#define TTV_LINE_J         ((long) 0x00000002 ) /* lien de type J            */
#define TTV_LINE_T         ((long) 0x00000004 ) /* lien de type T            */
#define TTV_LINE_F         ((long) 0x00000010 ) /* lien de type F            */
#define TTV_LINE_E         ((long) 0x00000020 ) /* lien de type E            */
#define TTV_LINE_D         ((long) 0x00000040 ) /* lien de type D            */
#define TTV_LINE_TYPE      ((long) 0x000000FF ) /* lien de type E            */

/* marquage des lines */
#define TTV_LINE_MARQUE    ((long) 0x10000000 ) /* lien marque               */
#define TTV_LINE_FR        ((long) 0x20000000 ) /* lien libre                */
#define TTV_LINE_INFIG     ((long) 0x40000000 ) /* lien dans la figure       */
#define TTV_LINE_HZ        ((long) 0x00000100 ) /* lien de type HZ           */
#define TTV_LINE_EV        ((long) 0x00000200 ) /* lien de type evaluation   */
#define TTV_LINE_PR        ((long) 0x00000400 ) /* lien de type precharge    */
#define TTV_LINE_RC        ((long) 0x00000800 ) /* lien de type rc           */
#define TTV_LINE_DEPTMAX   ((long) 0x00001000 ) /* lien D ou E dans un PT M  */
#define TTV_LINE_DEPTMIN   ((long) 0x00002000 ) /* lien D ou E dans un PT m  */
#define TTV_LINE_DENPTMAX  ((long) 0x00004000 ) /* lien D ou E pas dans PT M */
#define TTV_LINE_DENPTMIN  ((long) 0x00008000 ) /* lien D ou E pas dans PT m */
#define TTV_LINE_PREV      ((long) 0x00010000 ) /* lien avec un ptype prev   */
#define TTV_LINE_ROOT      ((long) 0x00020000 ) /* premier lien d'une liste  */
#define TTV_LINE_PREV_DUAL ((long) 0x00040000 ) /* lien avec un ptype prev   */
#define TTV_LINE_ROOT_DUAL ((long) 0x00080000 ) /* premier lien d'une liste  */

/* type user des lines */
#define TTV_LINE_CMDMAX    ((long) 0x00000001 ) /* command de lien pour max  */
#define TTV_LINE_CMDMIN    ((long) 0x00000002 ) /* command de lien pour min  */
#define TTV_LINE_PREVLINE  ((long) 0x00000003 ) /* lien precedant pour free  */
#define TTV_LINE_CARAC     ((long) 0x00000004 ) /* carac elec pour T ou D    */
#define TTV_LINE_PREVLDUAL ((long) 0x00000005 ) /* lien dual precedant       */

/* type de recherche de chemin */
#define TTV_FIND_MARQUE    ((long) 0x10000000 ) /* marquage de la recherche  */
#define TTV_FIND_MAX       ((long) 0x00000001 ) /* recherche des chemins max */
#define TTV_FIND_MIN       ((long) 0x00000002 ) /* recherche des chemins mix */
#define TTV_FIND_LINE      ((long) 0x00000010 ) /* recherche avec liens      */
#define TTV_FIND_PATH      ((long) 0x00000020 ) /* recherche avec chemins    */
#define TTV_FIND_HZ        ((long) 0x00000100 ) /* recherche des chemins HZ  */
#define TTV_FIND_PR        ((long) 0x00000200 ) /* recherche des chemins HZ  */
#define TTV_FIND_EV        ((long) 0x00000400 ) /* recherche des chemins HZ  */
#define TTV_FIND_HIER      ((long) 0x00001000 ) /* recherche stop a CB et CT */
#define TTV_FIND_DUAL      ((long) 0x00002000 ) /* recherche avec liens dual */
#define TTV_FIND_MASKOR    ((long) 0x00004000 ) /* recherche sans classement */
#define TTV_FIND_MASKAND   ((long) 0x00008000 ) /* recherche sans classement */
#define TTV_FIND_CRITIC    ((long) 0x00010000 ) /* recherche avec critic     */
#define TTV_FIND_NOTSAVE   ((long) 0x00020000 ) /* recherche sans sauvegarde */
#define TTV_FIND_NOTCLASS  ((long) 0x00040000 ) /* recherche sans classement */

/* type de fichier pour le driver et le parser */
#define TTV_FILE_TTX       ((long) 0x00000001 ) /* fichier ttx               */
#define TTV_FILE_DTX       ((long) 0x00000002 ) /* fichier dtx               */
#define TTV_FILE_TTV       ((long) 0x00000004 ) /* fichier ttv               */
#define TTV_FILE_DTV       ((long) 0x00000008 ) /* fichier dtv               */

/* delai et front des evenements et des liens */
#define TTV_NOTIME         ((long) 0x80000000 ) /* pas de temps              */
#define TTV_NOSLOPE        ((long) 0x80000000 ) /* pas de front              */
#define TTV_NORES          ((long) 0x00000000 ) /* pas de resistance         */
#define TTV_NOS            ((long) 0x00000000 ) /* pas de s                  */

/* STRUCTURES DE TTV */

typedef struct ttvevent                         /* evenement d'un signal     */
    {
     struct ttvsig       *ROOT ;                /* pointeur sur le signal    */
     long                 TYPE ;                /* type de signal            */
     struct ttvline      *INLINE ;              /* lien de l'evenement       */
     struct ttvline      *INPATH ;              /* chemin de l'evenement     */
     long                 DELAY ;               /* delay pour les parcours   */
     struct ttvline      *OUTLINE ;             /* retour de chemin          */
     struct ptype        *USER ;                /* champs utilisateur        */ 
    }
ttvevent_list ;

typedef struct ttvsig                           /* signal pour le timing     */
    {
     char                *NAME ;                /* nom du signal             */
     struct ttvfig       *ROOT ;                /* ttvfig du signal          */
     long                 TYPE ;                /* type de signal            */
     struct ttvevent      NODE[2] ;             /* 2 evenement du signal     */
     struct ptype        *USER ;                /* champs utilisateur        */ 
    }
ttvsig_list ;

typedef struct ttvsbloc                         /* liste de blocs de signaux */
    {
     struct ttvsbloc     *NEXT ;                /* next pour liste chainee   */
     struct ttvsig        SIG[TTV_MAX_SBLOC] ;  /* tableau de signaux        */
    }
ttvsbloc_list ;

typedef struct ttvcaracsig                      /* carac pour CQIN poud htas */
    {
     struct ttvcaracsig  *NEXT ;                /* champs next pour alloc    */
     struct ttvfig       *ROOT ;                /* ttvfig de la carac        */
     struct ttvsig       *CON ;                 /* connecteur associe        */
     long                 C ;                   /* capacite associe          */
     long                 RUMAX ;               /* resistance up max         */
     long                 RDMAX ;               /* resistance down max       */
     long                 RUMIN ;               /* resistance up min         */
     long                 RDMIN ;               /* resistance down min       */
     long                 FUMAX ;               /* front up max              */
     long                 FDMAX ;               /* front down min            */
     long                 FUMIN ;               /* front up max              */
     long                 FDMIN ;               /* front down min            */
    }
ttvcaracsig_list ;

typedef struct ttvcaracline                    /* carac pour T D pour htas   */
    {
     struct ttvcaracline *NEXT ;               /* champs next pour alloc     */
     long                 RMAX ;               /* correction de t max avec C */
     long                 RMIN ;               /* correction de t min avec C */
     long                 SMAX ;               /* correction de t max avec F */
     long                 SMIN ;               /* correction de t min avec F */
    }
ttvcaracline_list ;

typedef struct ttvline                         /* lien entre evenement       */
    {
     struct ttvline      *NEXT ;               /* champs next pour liste     */
     struct ttvfig       *FIG ;                /* ttvfif pere du lien        */
     struct ttvevent     *ROOT ;               /* evenement destination      */
     long                 TYPE ;               /* type de lien               */
     struct ttvevent     *NODE ;               /* evenement source           */
     long                 VALMAX ;             /* valeur du temps max        */
     long                 FMAX ;               /* valeur du front max        */
     long                 VALMIN ;             /* valeur du temps min        */
     long                 FMIN ;               /* valeur du front min        */
     struct ptype        *USER ;               /* champs utilisateur         */
    }
ttvline_list ;

typedef struct ttvlbloc                        /* liste de blocs de liens    */
    {
     struct ttvlbloc     *NEXT ;               /* next pour liste chainee    */
     struct ttvline       LINE[TTV_MAX_LBLOC] ;/* tableau de liens           */
    }
ttvlbloc_list ;

typedef struct ttvcritic                       /* detail de chemin           */
    {
     struct ttvcritic    *NEXT ;               /* noeud suivant              */
     struct ttvfig       *FIG ;                /* figure du delay            */
     char                *NAME ;               /* nom du noeud               */
     long                 TYPE ;               /* type de recherche          */
     long                 DELAY ;              /* delay                      */
     long                 SLOPE ;              /* front                      */
     char                 SNODE ;              /* type de front              */
    }
ttvcritic_list ;

typedef struct ttvpath                         /* detail de chemin           */
    {
     struct ttvpath      *NEXT ;               /* noeud suivant              */
     struct ttvfig       *FIG ;                /* figure du delay            */
     struct ttvevent     *ROOT ;               /* noeud d'arrive             */
     struct ttvevent     *NODE ;               /* noeud de depart            */
     struct ttvevent     *CMD ;                /* command                    */
     long                 TYPE ;               /* type de recherche          */
     long                 DELAY ;              /* delay                      */
     long                 SLOPE ;              /* front                      */
    }
ttvpath_list ;

typedef struct ttvinfo                        /* information sur la ttvfig   */
    {
     char                *TOOLNAME ;          /* outil tas ou htas           */
     char                *TOOLVERSION ;       /* version de l'outil          */
     char                *TECHNONAME ;        /* technologie elp             */
     char                *TECHNOVERSION ;     /* version de la technologie   */
     int                  TTVYEAR ;           /* annee de generation         */
     int                  TTVMONTH ;          /* mois de generation          */
     int                  TTVDAY ;            /* jour de generation          */
     int                  TTVHOUR ;           /* heure de generation         */
     int                  TTVMIN ;            /* minute de generation        */
     int                  TTVSEC ;            /* seconde de generation       */
     long                 SLOPE ;             /* front d'entree utilser      */
     long                 CAPAOUT ;           /* capacite utiliser en sortie */
    }
ttvinfo_list ;

typedef struct ttvfig                         /* figure ttv                  */
    {
     struct ttvfig       *NEXT ;              /* ttvfig suivante de la liste */
     struct ttvfig       *ROOT ;              /* ttvfig pere de la ttvfig    */
     long                 OLD ;               /* age de la ttvfig            */
     long                 LEVEL ;             /* niveau hierarchique         */
     char                *FIGNAME ;           /* nom de modele               */
     char                *INSNAME ;           /* nom d'instance              */
     long                 STATUS ;            /* etat de la ttvfig           */
     struct ttvinfo       INFO ;              /* information sur la ttvfig   */
     struct ttvsig      **CONSIG ;            /* tableau des connecteurs     */
     long                 NBCONSIG ;          /* nb de connecteurs           */
     struct ttvsig      **NCSIG ;             /* tableau des extremites RC   */
     long                 NBNCSIG ;           /* nb des extremites RC        */
     struct chain        *INS ;               /* liste des instances         */
     struct ttvsig      **ELCMDSIG ;          /* tableau des commands ext    */
     long                 NBELCMDSIG ;        /* nb de commands ext          */
     struct ttvsig      **ILCMDSIG ;          /* tableau des commands int    */
     long                 NBILCMDSIG ;        /* nb de commands int          */
     struct ttvsig      **ELATCHSIG ;         /* tableau des latchs ext      */
     long                 NBELATCHSIG ;       /* nb de latchs ext            */
     struct ttvsig      **ILATCHSIG ;         /* tableau des latchs int      */
     long                 NBILATCHSIG ;       /* nb de latchs int            */
     struct ttvsig      **EPRESIG ;           /* tableau des precharges ext  */
     long                 NBEPRESIG ;         /* nb de precharges ext        */
     struct ttvsig      **IPRESIG ;           /* tableau des precharges int  */
     long                 NBIPRESIG ;         /* nb de precharges int        */
     struct ttvsig      **EXTSIG ;            /* tableau des signaux exter   */
     long                 NBEXTSIG ;          /* nb de signaux exter         */
     struct ttvsig      **INTSIG ;            /* tableau des signaux inter   */
     long                 NBINTSIG ;          /* nb de signaux inter         */
     struct ttvsig      **ESIG ;              /* tableau des signaux externe */
     long                 NBESIG ;            /* nb de signaux externe       */
     struct ttvsbloc     *ISIG ;              /* tableau des signaux interne */
     long                 NBISIG ;            /* nb de signaux interne       */
     struct ttvlbloc     *PBLOC ;             /* tableau de chemin complet   */
     long                 NBPBLOC ;           /* nb de chemin complet        */
     struct ttvlbloc     *JBLOC ;             /* tableau de chemin sur T     */
     long                 NBJBLOC ;           /* nb de chemin sur T          */
     struct ttvlbloc     *TBLOC ;             /* tableau de chemin incomplet */
     long                 NBTBLOC ;           /* nb de chemin incomplet      */
     struct ttvlbloc     *FBLOC ;             /* tableau de liens interne    */
     long                 NBFBLOC ;           /* nb de liens interne         */
     struct ttvlbloc     *EBLOC ;             /* tableau de liens complet    */
     long                 NBEBLOC ;           /* nb de liens complet         */
     struct ttvlbloc     *DBLOC ;             /* tableau de liens incomplet  */
     long                 NBDBLOC ;           /* nb de liens incomplet       */
     struct ptype        *USER ;              /* champs utilisateur          */
    }
ttvfig_list ;

/* VARIABLES DE TTV */

extern ttvfig_list *TTV_LIST_TTVFIG ;
extern long TTV_SEUIL_MAX ;
extern long TTV_SEUIL_MIN ;
extern long TTV_INFO_CAPARM ;
extern long TTV_INFO_CAPASW ;
extern short TTV_INFO_ARGC ;
extern char **TTV_INFO_ARGV ;
extern char TTV_PATH_SAVE ;
extern char *TTV_INFO_TOOLDATE ;
extern chain_list *TTV_NAME_IN ;
extern chain_list *TTV_NAME_OUT ;
extern char TTV_LANG ;
extern long TTV_NUMB_SIG ;
extern long TTV_NUMB_LINE ;
extern long TTV_MAX_SIG ;
extern long TTV_MAX_LINE ;

/* FONCTION DE TTV */

extern ttvfig_list *ttv_allocttvfig() ;
extern int ttv_freettvfig() ;
extern int ttv_freeallttvfig() ;
extern int ttv_freepathlist() ;
extern int ttv_freecriticlist() ;
extern ttvsig_list **ttv_allocreflist() ;
extern int ttv_freereflist() ;
extern ttvcaracsig_list *ttv_alloccaracsig() ;
extern int ttv_freecaracsig() ;
extern ttvcaracline_list *ttv_alloccaracline() ;
extern int ttv_freecaracline() ;
extern int ttv_freettvfigmemory() ;
extern void ttv_fifopush() ;
extern ttvevent_list *ttv_fifopop() ;
extern void ttv_fifoclean() ;
extern void ttv_fifodelete() ;
extern ttvcritic_list *ttv_getcritic() ;
extern ttvpath_list *ttv_getcriticpath() ;
extern ttvpath_list *ttv_getpath() ;
extern chain_list *ttv_getcriticpara() ;
extern int ttv_freecriticpara() ;
extern ttvpath_list *ttv_getpara() ;
extern void ttv_builtpath() ;
extern char ttv_getdir() ;
extern void ttv_drittv() ;
extern void ttv_drittvold() ;
extern void ttv_detectinter() ;
extern ttvsig_list *ttv_addsig() ;
extern chain_list *ttv_addrefsig() ;
extern void ttv_delrefsig() ;
extern ttvline_list *ttv_addline() ;
extern int ttv_delline() ;
extern ttvcaracsig_list *ttv_getcaracsig() ;
extern ttvcaracline_list *ttv_getcaracline() ;
extern ttvevent_list *ttv_getcmd() ;
extern ptype_list *ttv_addcmd() ;
extern chain_list *ttv_getlrcmd() ;
extern ttvfig_list *ttv_getttvfig() ;
extern ttvfig_list *ttv_givettvfig() ;
extern chain_list *ttv_getttvfiglist() ;
extern char *ttv_getsigname() ;
extern ttvsig_list *ttv_getsigbyname() ;
extern ttvsig_list *ttv_getsigbyinsname() ;
extern ttvsig_list *ttv_getsigbyindex() ;
extern chain_list *ttv_getsigbytype() ;
extern chain_list *ttv_getsignamelist() ;
extern void ttv_freenamelist() ;
extern chain_list *ttv_getallsigbytype() ;
extern void ttv_setsiglevel() ;
extern long ttv_getsiglevel() ;
extern void ttv_detsiglevel() ;
extern ttvfig_list *ttv_parsttvfig() ;
extern char *ttv_revect() ;
extern char *ttv_devect() ;
extern int ttv_testmask() ;
extern void ttv_checkfigins() ;
extern void ttv_checkallinstool() ;
extern void ttv_setttvlevel() ;
extern void ttv_setttvdate() ;
extern void ttv_setcachesize() ;

#endif
